import axios from "axios";
import {id} from "element-plus/es/locale/index";

const instance = axios.create({
    baseURL: 'http://localhost:8888',
})

export default {
    login(form) {
        const formData = new FormData();
        formData.append('username', form.username);
        formData.append('password', form.password);
        return instance.post("/zoo/login/login", formData);
    },

    //用户请求
    addUserRequest(user) {
        return instance.post("/zoo/account/save", backendUser(user));
    },
    deleteUserRequest(id) {
        return instance.get("/zoo/account/delete", {params: {id}});
    },
    updateUserRequest(user) {
        return instance.post("/zoo/account/update", backendUser(user));
    },
    queryUserRequest(id) {
        return instance.get("/zoo/account/info", id)
    },

    //动物请求
    addAnimalRequest(animal) {
        return instance.post("/zoo/animal/add", backendAnimal(animal));
    },
    deleteAnimalRequest(aid) {
        return instance.get("/zoo/animal/delete", {params: {aid}});
    },
    updateAnimalRequest(animal) {
        return instance.post("/zoo/animal/update", backendAnimal(animal));
    },
    queryAnimalRequest(aid) {
        return instance.get("/zoo/animal/info", {params: {aid}})
    },

    //饲养计划请求
    addBreedingPlanRequest(breedingPlan) {
        return instance.post("/zoo/plan/add", backendBreeding(breedingPlan));
    },
    deleteBreedingPlanRequest(id) {
        return instance.get("/zoo/plan/delete", {params: {id}})
    },
    updateBreedingPlanRequest(breedingPlan) {
        return instance.post("/zoo/plan/update", backendBreeding(breedingPlan));
    },
    queryBreedingPlanRequest(id) {
        return instance.get("/zoo/plan/info", {params: {id}})
    },

    //档案请求
    addArchiveRequest(archive) {
        return instance.post("/com/zoo/archive/add", backendArchive(archive));
    },
    deleteArchiveRequest(id) {
        return instance.get("/com/zoo/archive/delete", {params: {id}})
    },
    updateArchiveRequest(archive) {
        return instance.post("/com/zoo/archive/update", backendArchive(archive));
    },
    queryArchiveRequest(id) {
        return instance.get("/com/zoo/archive/info", {params: {id}})
    },

    //健康记录请求
    addHealthRequest(health) {
        return instance.post("/com/zoo/health/add", backendHealth(health));
    },
    deleteHealthRequest(id) {
        return instance.get("/com/zoo/health/delete", {params: {id}})
    },
    updateHealthRequest(health) {
        return instance.post("/com/zoo/health/update", backendHealth(health));
    },
    queryHealthRequest(id) {
        return instance.get("/com/zoo/health/info", {params: {id}})
    }
}

// export function getUserById(id) {
//     const data = store.state.users.find(e => e.id === id);
//
//     return data;
// }

// 将后端对象转化为符合前端需求的对象
export function frontendLoginUser(data) {
    return {
        id: data.id,
        username: data.username,
        auth: data.permissions
    };
}

export function frontendUsers(users){
    const newUsers = []
    users.forEach(user => {
        newUsers.push(frontendUser(user));
    })
    return newUsers
}

export function frontendUser(user){
    return {
        id: user.id,
        username: user.username,
        password: user.password,
        auth: user.permissions
    }
}

export function frontendAnimals(animals) {
    const newAnimals = []
    animals.forEach((element) => {
        newAnimals.push(frontendAnimal(element))
    })
    return newAnimals
}

export function frontendAnimal(animal) {
    return {
        id: animal.aId,
        name: animal.name,
        sex: animal.sex,
        species: animal.species,//种类
        weight: animal.weight,
        height: animal.height,
        state: animal.state,//状态（0正常 1异常）
        roleId: animal.roleid,//饲养员id
        color: animal.color,//颜色
        features: animal.features,//特征
        phase: animal.phase//生长阶段
    }
}

// 将前端对象的属性转为能和后端对应上属性的对象
export function backendUser(user) {
    return {
        id: user.id,
        username: user.username,
        password: user.password,
        permissions: user.auth
    }
}

export function backendAnimal(animal) {
    return {
        aId: animal.id,
        name: animal.name,
        sex: animal.sex,
        species: animal.species,
        weight: animal.weight,
        height: animal.height,
        state: animal.state,
        roleid: animal.roleId,
        color: animal.color,
        features: animal.features,
        phase: animal.phase
    }
}

export function backendBreeding(breeding) {
    return {
        id: breeding.id,
        name: breeding.name,
        species: breeding.species,
        sex: breeding.sex,
        phase: breeding.phase,
        state: breeding.state,
        roleid: breeding.roleId,
        description: breeding.description,
    }
}

export function backendArchive(archive) {
    return {
        id: archive.id,
        animallId: archive.animalId,
        animalName: archive.animalName,
        phase: archive.phase,
        state: archive.state,
        type: archive.type,
        date: archive.date,
        time: archive.time,
        roleId: archive.roleId,
        description: archive.description,
    }
}

export function backendHealth(health) {
    return {
        id: health.id,
        animalId: health.animalId,
        animalName: health.animalName,
        state: health.state,
        temperature: health.temperature,
        breathRate: health.breathRate,
        heartRate: health.heartRate,
        bloodPressure: health.bloodPressure,
        date: health.date,
        time: health.time,
        description: health.description
    }
}